<roundcube:object name="doctype" value="html5" />
<html>
<head>
<title><roundcube:object name="pagetitle" /></title>
<roundcube:include file="/includes/links.html" />
<link rel="stylesheet" type="text/css" href="/this/sauserprefs.css" />
</head>
<body class="iframe">

<h1 class="boxtitle"><roundcube:object name="sectionname" /></h1>

<div id="preferences-details" class="boxcontent">
<roundcube:object name="userprefs" form="form" class="propform" />
</div>

<div class="footerleft formbuttons">
<roundcube:button command="plugin.sauserprefs.save" type="input" class="button mainaction" label="save" />
<roundcube:button command="plugin.sauserprefs.default" type="input" class="button" label="sauserprefs.usedefault" style="margin-right:0.5em" />
</div>

<roundcube:include file="/includes/footer.html" />

</body>
</html>