/**
 * SAUserPrefs plugin styles
 */

#address-rules-cont,
#spam-langs-cont
{
  border: 1px solid #999999;
  background-color: #F9F9F9;
  height: 200px;
  overflow: auto;
  width: 510px;
}

body.address-rules-table,
body.spam-langs-table
{
  margin: 0px;
  background-color: #F9F9F9;
}

table.address-rules-table,
table.spam-langs-table
{
  width: 100%;
  display: table;
  table-layout: fixed;
  border-collapse: collapse;
  border-spacing: 0px;
}

table.address-rules-table thead th.rule
{
  width: 180px;
}

table.address-rules-table thead th.control
{
  width: 40px;
}

table.address-rules-table thead th a,
table.spam-langs-table thead th a
{
  display: block;
  text-decoration: none;
}

table.address-rules-table thead th.sortedASC,
table.address-rules-table thead th.sortedDESC,
table.spam-langs-table thead th.sortedASC,
table.spam-langs-table thead th.sortedDESC
{
  background-position: 0px -26px;
}

table.spam-langs-table tr > .lang
{
  width: 80%;
}

table.spam-langs-table tr > .tick
{
  width: 20%;
}

table.spam-langs-table thead th.tick a
{
  padding-right: 24px;
}

table.address-rules-table thead tr th.sortedASC a,
table.spam-langs-table thead tr th.sortedASC a
{
  background: url(images/sort.gif) no-repeat right -14px;
}

table.address-rules-table thead tr th.sortedDESC a,
table.spam-langs-table thead tr th.sortedDESC a
{
  background: url(images/sort.gif) no-repeat right 0;
}

table.spam-langs-table tr > .lang,
table.address-rules-table tr > .rule,
table.address-rules-table tr > .email
{
  text-align: left;
  vertical-align: middle;
}

table.spam-langs-table tr > .tick,
table.address-rules-table tr > .control
{
  text-align: right;
  vertical-align: middle;
}

table.spam-langs-table tbody td.tick a,
table.address-rules-table tr > .control a
{
  display: block;
  float: right;
  width: 16px;
  height: 16px;
  background-image: url(images/icons.png);
}

table.address-rules-table tr > .control a.delete
{
  background-position: 0 0;
}

table.spam-langs-table tr > .tick a.enabled
{
  background-position: 0 -18px;
}

table.spam-langs-table tr > .tick a.disabled
{
  background-position: 0 -36px;
}

.whitelist_from,
.whitelist_to
{
  color: #008800;
  text-align: left;
  vertical-align: middle;

}

.blacklist_from
{
  color: #BB0000;
  text-align: left;
  vertical-align: middle;
}

#listcontrols
{
  font-size: 11px;
  text-align: right;
}

#listcontrols a,
#listcontrols a:active,
#listcontrols a:visited
{
  color: #CC0000;
  font-size: 11px;
  text-decoration: none;
}

#listcontrols a:hover
{
  text-decoration: underline;
}

table.generalprefstable,
table.headersprefstable,
table.testsprefstable,
table.bayesprefstable,
table.reportprefstable
{
  width: 100%;
}

table.generalprefstable tr > .title
{
  width: 115px;
}

table.headersprefstable tr > .title
{
  width: 220px;
}

table.testsprefstable tr > .title
{
  width: 175px;
}

table.bayesprefstable tr > .title
{
  width: 220px;
}

table.reportprefstable tr > .title
{
  width: 320px;
}

table.generalprefstable tr > .help,
table.langprefstable tr > .help,
table.headersprefstable tr > .help,
table.testsprefstable tr > .help,
table.bayesprefstable tr > .help,
table.reportprefstable tr > .help,
table.addressprefstable tr > .help
{
  text-align: right;
}

table.addressprefstable tr > .ruletype
{
  width: 180px;
  padding-bottom: 10px;
}

table.addressprefstable tr > .address
{
  width: 220px;
  padding-bottom: 10px;
}

table.addressprefstable tr > .action
{
  width: 100px;
  text-align: right;
  padding-bottom: 10px;
}

table.langprefstable tr > .scroller,
table.addressprefstable tr > .scroller
{
  padding: 0;
}

span.helpicon {
  display: inline-block;
  width: 16px;
  height: 16px;
  background-image: url(images/icons.png);
  background-position: 0 -57px;
}

#rcmfd_spamlevelchar {
  width: 20px;
}

#rcmfd_spamsubject,
#rcmfd_spamaddress {
  width: 200px;
}