<?php
/* Author: Reino Wallin */

$labels = array();
$labels['sauserprefs'] = 'Skräppost';
$labels['sauserprefssettings'] = 'Inställningar för skräppost';
$labels['spamgeneralsettings'] = 'Allmänna inställningar';
$labels['spamthres'] = 'Tröskelvärde';
$labels['spamsubject'] = 'Rubrikmärkning';
$labels['spamsubjectblank'] = '(lämna tom om du inte vill lägga till någon text till rubriken)';
$labels['spamlang'] = 'Brevets språk';
$labels['enabled'] = 'Aktiverad';
$labels['disabled'] = 'Ej aktiverad';
$labels['headers'] = 'Brevhuvud';
$labels['foldheaders'] = 'Tillåt flera rader i brevhuvudet';
$labels['spamlevelstars'] = 'Använd \'Spam Level\' i brevhuvudet';
$labels['spamlevelchar'] = 'Tecken för \'Spam Level\'';
$labels['spamtests'] = 'Internetbaserade tester av skräppost';
$labels['userazor1'] = 'Använd Razor v1';
$labels['userazor2'] = 'Använd Razor v2';
$labels['usepyzor'] = 'Använd Pyzor';
$labels['usebayes'] = 'Använd bayesklassificering';
$labels['usedcc'] = 'Använd DCC';
$labels['skiprblchecks'] = 'Använd svartlistor i realtid';
$labels['spamreportsettings'] = 'Rapportinställningar';
$labels['spamreport0'] = 'Lägg till rapporten till originalbrevets brevhuvud';
$labels['spamreport1'] = 'Sänd rapporten med originalbrevet som en MIME-bilaga';
$labels['spamreport2'] = 'Sänd rapporten med originalbrevet som en text-bilaga';
$labels['spamaddressrules'] = 'Adressregler';
$labels['whitelist_from'] = 'Acceptera brev från';
$labels['blacklist_from'] = 'Avvisa brev från';
$labels['whitelist_to'] = 'Acceptera brev till';
$labels['addrule'] = 'Lägg till';
$labels['rule'] = 'Regel';
$labels['importfromaddressbook'] = 'Importera adresser från adressboken';
$labels['deleteall'] = 'Radera alla';
$labels['autoscore'] = 'Auto';
$labels['defaultscore'] = 'Använd grundinställningar';
$labels['otherscore'] = 'Annan (%s)';
$labels['usedefault'] = 'Återställ grundinställningar';
$labels['langoptions'] = 'Språkinställningar';
$labels['bayes'] = 'Bayesinställningar';
$labels['purgingbayes'] = 'Raderar bayesdata...';
$labels['purgebayes'] = 'Radera personliga bayesdata';
$labels['bayesautolearn'] = 'Använd bayesinlärning';
$labels['bayesautooptions'] = 'Inställningar för inlärning';
$labels['bayesnonspam'] = 'Tröskelvärde för vanliga brev';
$labels['bayesspam'] = 'Tröskelvärde för skräppost';
$labels['bayesrules'] = 'Använd bayesregler';
$labels['help'] = 'Hjälp';

$messages = array();
$messages['sauserprefchanged'] = 'Dina inställningar för skräppost har sparats';
$messages['sauserpreffailed'] = 'Fel: Det går inte att spara dina inställningar för skräppost';
$messages['spamthresexp'] = 'Alla brev som vid granskningen av SpamAssassin får ett värde som överstiger tröskelvärdet för skräppost blir märkta som skräppost. Ökar man tröskelvärdet innebär det att viss skräppost inte blir märkt som skräppost, men man reducerar också risken att vanliga brev blir märkta som skräppost.';
$messages['spamlangexp'] = 'Välj de språk du förväntar dig att mottagna brev är skrivna på. Brev som är skrivna på andra språk än de du inte valt kommer att bli betrakade som möjlig skräppost';
$messages['headersexp'] = 'SpamAssassin lägger till information i brevhuvudet på brev som granskats av SpamAssassin. Informationen beskriver resultatet av granskningen. Använd inställningarna nedan för att konfigurera dessa brevhuvuden.';
$messages['spamtestssexp'] = 'Vissa kontroller som SpamAssassin utför för att karaktärisera ett brev, baseras på tjänster på Internet. Välj de tjänster du önskar använda dig av:';
$messages['spamreport'] = 'När ett brev karaktäriseras som skräppost skapas en rapport med alla resulten från granskningen som SpamAssassin gör...';
$messages['autowhitelist'] = 'Lägg per automatik till adresserna i din adressbok till \'Acceptera brev från\' listan.';
$messages['whitelistexp'] = 'Du kan använda en asterisk (*) för att skapa ett mer flexibelt regelverk, exempelvis: *@example.com eller *.example.com.';
$messages['spamaddressexists'] = 'En regel finns redan för denna adressen';
$messages['spamenteraddress'] = 'Ange en adress att lägga till';
$messages['spamaddresserror'] = 'Fel: Ogiltlig adress';
$messages['spamaddressdelete'] = 'Är du säker på att du vill radera denna adressregel?';
$messages['spamaddressdeleteall'] = 'Är du säker på att du vill radera alla adressregler?';
$messages['noaddressrules'] = 'Det existerar inga adressregler.';
$messages['importingaddresses'] = 'Importerar adresser...';
$messages['usedefaultconfirm'] = 'Är du säker på att du vill återställa grundinställninganra? Om så sker raderar du dina nuvarande inställningar, som exempelvis dina adressregler.';
$messages['purgebayesexp'] = 'Radera personliga bayesdata som samlats in från dina brev';
$messages['bayesnonspamexp'] = 'Brev som erhåller ett skräppostvärde under detta tröskelvärde kommer att användas för att förbättra skräppostsystemets förmåga att identifiera brev som inte är skräppost.';
$messages['bayesspamexp'] = 'Brev som erhåller ett skräppostvärde över detta tröskelvärde kommer att användas för att förbättra skräppostsystemets förmåga att identifiera skräppost.';
$messages['bayesautohelp'] = 'Om bayesinlärning är aktiverat kommer skräppostsystemet att vid granskningen av brev, som med stor sannolikhet är spräppost eller med stor sannolikhet är vanliga brev, att automatiskt uppdatera sin databas och förbättra sin förmåga att detektera skräppost. Brev som är mer svårbedömda kommer inte att användas vid inlärningen';
$messages['bayeshelp'] = 'Vid klassificering av brev baserat på Bayes försöker man identifiera spräppost med hjälp av ord, eller korta bokstavssekvenser, som är vanligt förekommande i vanliga brev respektive skräppost.';
$messages['rblhelp'] = 'Serveradresser som finns i länkar infogade i brev kommer att kontrolleras mot ett flertal \'svartlistor\' och listor över välkända källor för skräppost.';
$messages['dcchelp'] = 'DCC (Distributed Checksum Clearinghouse) är en internettjänst baserad på ett antal sevrar som dagligen samlar in och beräknar checksumman för miljontals brev. Checksumman för inkommande brev jämförs med data i databasen och desto större likhet som råder desto större sannolikhet är det att brevet är att betrakta som skräppost.';
$messages['pyzhelp'] = 'Pyzor är en distribuerad internettjänst för att detektera skräppost. Den baseras på att man beräknar en checksumma av brevet som kontrolleras mot nätverksbaserade databaser för att se om andra har klassificerat brevtexten som skräppost.';
$messages['raz2help'] = 'Vipul\'s Razor är en distribuerad internettjänst för att detektera skräppost. Den baseras på att man beräknar en checksumma av brevet som kontrolleras mot nätverksbaserade databaser för att se om andra har klassificerat brevtexten som skräppost. Razor är effektivt även när det gäller så kallade muterade brevtexter.';
$messages['levelhelp'] = 'Brevhuvudet benämnt \'Spam Level\', som visar hur brevet klassificerats, kan läggas till breven och underlätta för vidare behandling.';
$messages['foldhelp'] = 'Skall de brevhuvud som SpamAssassin lägger till brevet struktureras som en lång rad eller ett flertal separata brevhuvud.';
$messages['bayesruleshlp'] = 'Innan bayesklassificering kan göras effektivt måste en inlärning av vad som är spräppost respektive vanliga brev ske. Om man inte väljer att använda bayesklassificering kommer skräppostsystemet att öka sin förmåga att detektera skräppost genom både manuellt och automatiskt inlärning, men klassificering kommer inte att ske.';
$messages['purgebayesconfirm'] = 'Är du säker på att du vill radera alla dina bayesdata?';
