<?php
/* Author: Sergey Khaliulov 
   Updates: Vladislav Bogdanov
*/

$labels = array();
$labels['sauserprefs'] = 'Спам фильтр';
$labels['sauserprefssettings'] = 'Настройки спам фильтра';
$labels['spamgeneralsettings'] = 'Основные параметры';
$labels['spamthres'] = 'Порог оценки';
$labels['spamsubject'] = 'Метка спама в теме сообщения';
$labels['spamsubjectblank'] = '(оставьте пустым, чтобы не менять тему сообщения)';
$labels['spamlang'] = 'Языки сообщения';
$labels['enabled'] = 'Включен';
$labels['disabled'] = 'Отключен';
$labels['headers'] = 'Заголовки сообщения';
$labels['foldheaders'] = 'Разрешить многострочные записи в заголовках';
$labels['spamlevelstars'] = 'Использовать заголовок \'Spam Level\'';
$labels['spamlevelchar'] = 'Символ уровня спама';
$labels['spamtests'] = 'Internet-проверки';
$labels['userazor1'] = 'Использовать Razor v1';
$labels['userazor2'] = 'Использовать Razor v2';
$labels['usepyzor'] = 'Использовать Pyzor';
$labels['usebayes'] = 'Включить "наивный" Байесовский классификатор';
$labels['usedcc'] = 'Использовать DCC';
$labels['skiprblchecks'] = 'Использовать Черные Списки адресов (RBL)';
$labels['spamreportsettings'] = 'Параметры уведомления';
$labels['spamreport0'] = 'Добавить отчет в заголовки оригинального сообщения';
$labels['spamreport1'] = 'Добавить в отчет оригинал письма как MIME вложение';
$labels['spamreport2'] = 'Добавить в отчет оригинал письма как текст';
$labels['spamaddressrules'] = 'Фильтры по адресу';
$labels['whitelist_from'] = 'Принимать письма от:';
$labels['blacklist_from'] = 'Отбрасывать письма от:';
$labels['whitelist_to'] = 'Принимать полученные для:';
$labels['addrule'] = 'Добавить';
$labels['rule'] = 'Правило';
$labels['importfromaddressbook'] = 'Импортировать адреса из Адресной книги';
$labels['deleteall'] = 'Удалить все';
$labels['autoscore'] = 'Auto';
$labels['defaultscore'] = 'По умолчанию';
$labels['otherscore'] = 'Другой (%s)';
$labels['usedefault'] = 'Восстановить настройки по умолчанию';
$labels['langoptions'] = 'Языки';
$labels['bayes'] = 'Байесовский фильтр';
$labels['purgingbayes'] = 'Удаляется статистика Байесовского фильтра...';
$labels['purgebayes'] = 'Удалить собранную статистику';
$labels['bayesautolearn'] = 'Включить авто-обучение Байесовского фильтра';
$labels['bayesautooptions'] = 'Параметры авто-обучения';
$labels['bayesnonspam'] = 'Граница не-СПАМа';
$labels['bayesspam'] = 'Граница СПАМа';
$labels['bayesrules'] = 'Использовать Байесовский фильтр для оценки сообщений';
$labels['help'] = 'Помощь';

$messages = array();
$messages['sauserprefchanged'] = 'Параметры фильтрации спама изменены';
$messages['sauserpreffailed'] = 'Ошибка: Невозможно изменить параметры';
$messages['spamthresexp'] = 'Система фильтрации спама использует числовые оценки для классификации сообщений. Используется большое количество тестов, каждый из которых возвращает определенное числовое значение при соответствии сообщения этому тесту. Результаты всех тестов суммируются для получения общей числовой оценки сообщения. При превышении полученной оценкой указанного порога - сообщение помечается как спам. Увеличение этого порога увеличит количество пропущенного спама, но и уменьшит риск ложных срабатываний. Общепринятым значением оценки, разделяющим СПАМ и не-СПАМ является число 5. Сообщения с оценкой более 8 практически в 100% случаев являются спамом.';
$messages['spamlangexp'] = 'Любые полученные сообщения, которые написаны не на выбранном языке будут рассматриваться в качестве возможного спама.';
$messages['headersexp'] = 'SpamAssassin добавляет в заголовки проверенных сообщений записи с информацией о результатах проверки. Укажите параметры добавляемых заголовков:';
$messages['spamtestssexp'] = 'Некоторые алгоритмы проверки на спам используют интернет сервисы. Выберите те, которые Вы желаете использовать:';
$messages['spamreport'] = 'Если сообщение идентифицировано как спам, сообщение должно быть сформировано следующим образом:';
$messages['autowhitelist'] = 'Адреса электронной почты в Вашей Адресной книге могут быть автоматически добавлены к списку "Принимать письма от" (белый список).';
$messages['whitelistexp'] = 'Звездочка (*) может использоваться как групповой символ для большей гибкости. Например: *@example.com или *.example.com. В общем случае не следует заносить много адресов в список "Отбрасывать письма от" (черный список), так как большинство адресов отправителей используются для рассылки спама только один раз. Этот список стоит использовать только в исключительных случаях, для блокирования писем от особо навязчивых нежелательных корреспондентов.';
$messages['spamaddressexists'] = 'Правило уже существует для этого адреса';
$messages['spamenteraddress'] = 'Введите адрес для добавления правила';
$messages['spamaddresserror'] = 'Ошибка: Адрес указан неверно';
$messages['spamaddressdelete'] = 'Вы дествительно хотите удалить это правило?';
$messages['spamaddressdeleteall'] = 'Вы уверены что хотите удалить все правила фильтрации по адресу?';
$messages['noaddressrules'] = 'Правил фильтрации по адресу не найдено.';
$messages['importingaddresses'] = 'Импорт адресов...';
$messages['usedefaultconfirm'] = 'Вы уверены, что Вы хотите восстановить настройки по умолчанию? Это удалит все Ваши настройки, включая правила проверки адреса.';
$messages['purgebayesexp'] = 'Удалить все данные, собранные Байсовским фильтром из Ваших сообщений';
$messages['bayesnonspamexp'] = 'Фильтр автоматически занесет сообщения, оценка которых НИЖЕ этого значения, в базу не-СПАМ сообщений.';
$messages['bayesspamexp'] = 'Фильтр автоматически занесет сообщения, оценка которых ВЫШЕ этого значения, в базу СПАМ сообщений.';
$messages['bayesautohelp'] = 'Позволяет автоматически заносить сообщения, с большой долей вероятности распознанные (при помощи других тестов) как СПАМ либо не-СПАМ, в соответствующие базы данных Байесовского фильтра.';
$messages['bayeshelp'] = 'Байесовский фильтр (также известен как "наивный" Байесовский классификатор) - это обучаемая система, собирающая статистику вхождения слов либо коротких последовательностей символов в СПАМ и не-СПАМ сообщения. При большом объеме данных (более 200 достаточно свежих сообщений каждого типа) Байесовский фильтр позволяет достаточно точно классифицировать последующие сообщения как СПАМ либо не-СПАМ.';
$messages['rblhelp'] = 'Адреса серверов, указанные в гипертекстовых ссылках, найденных в тексте сообщения, будут проверены в \'Черных Списках\', содержащих известные источники спама.';
$messages['dcchelp'] = 'DCC (Distributed Checksum Clearinghouse, Распределенный Центр Контрольных сумм) - это система, подсчитывающая количество похожих сообщений, принятых пользователями Internet по всему миру. Ежедневно обрабатывается более 300 миллионов сообщений. Чем больше количество похожих друг на друга сообщений - тем больше вероятность, что это спам. Внимание: сообщения популярных списков рассылки могут быть распознаны как спам с точки зрения DCC. Поэтому рекомендуется отфильтровывать такие сообщения до Спам-фильтра (например при помощи SIEVE-фильтров или Procmail-фильтров, если они поддерживаются сервером).';
$messages['pyzhelp'] = 'Pyzor is a collaborative, networked system to detect and block spam using identifying digests of messages.';
$messages['raz2help'] = 'Серверы системы Razor хранят большое количество контрольных сумм сообщений, зарегистрированных как спам многочисленными пользователями системы. Очень малое количество ложных срабатываний обеспечивается механизмом "репутации" пользователя.';
$messages['raz1help'] = 'Устаревшая и неподдерживаемая версия системы Razor. Используйте Razor v2.';
$messages['levelhelp'] = 'The \'Spam Level\' header can be added to a message to indicate the score given to a message by repeating a character a certain number of times.';
$messages['foldhelp'] = 'By default, headers added by SpamAssassin will be whitespace folded. In other words, they will be broken up into multiple lines instead of one very long one and each other line will have a tabulator prepended to mark it as a continuation of the preceding one.';
$messages['bayesruleshlp'] = 'Позволяет использовать данные, собранные при помощи автоматического и ручного методов обучения Байесовского фильтра, для классификации последующих сообщений. Внимание: для классификации требуется большая предварительно собранная база (по 200 свежих сообщений каждого типа). В противном случае фильтр не работает даже если эта опция включена.';
$messages['purgebayesconfirm'] = 'Вы уверены, что хотите удалить всю собранную статистику Байесовского фильтра?';
