<?php
/* Author: Simon Tauber */

$labels = array();
$labels['sauserprefs'] = 'Spam';
$labels['managespam'] = 'Verwalten der Spamfilter-Einstellungen';
$labels['sauserprefssettings'] = 'Spam Einstellungen';
$labels['spamgeneralsettings'] = 'Generelle Einstellugen';
$labels['spamthres'] = 'Schwellenwert';
$labels['spamsubject'] = 'Spam Betreff';
$labels['spamsubjectblank'] = '(Leer lassen um zu deaktivieren)';
$labels['spamlang'] = 'Mitteilungssprache';
$labels['enabled'] = 'Aktiviert';
$labels['disabled'] = 'Deaktiviert';
$labels['headers'] = 'Mitteilungsheaders';
$labels['foldheaders'] = 'Mehrzeilige Header erlauben';
$labels['spamlevelstars'] = '\'Spam Level\' Header verwenden';
$labels['spamlevelchar'] = 'Spam Level Symbol';
$labels['spamtests'] = 'Internet basierter Spam Test';
$labels['userazor1'] = 'Razor v1 verwenden';
$labels['userazor2'] = 'Razor v2 verwenden';
$labels['usepyzor'] = 'Pyzor verwenden';
$labels['usebayes'] = 'Naive Bayesische Stil Klassifizierung';
$labels['usedcc'] = 'DCC verwenden';
$labels['skiprblchecks'] = 'Echtzeit Blackhole Liste verwenden';
$labels['spamreportsettings'] = 'Berichtseinstellungen';
$labels['spamreport0'] = 'Bericht in den Header der Orginalnachricht einfügen';
$labels['spamreport1'] = 'Orginalmeldung dem Bericht als MIME Anhang hinzufügen';
$labels['spamreport2'] = 'Orginalmeldung dem Bericht als Text Anhang hinzufügen';
$labels['spamaddressrules'] = 'Adressregeln';
$labels['whitelist_from'] = 'Mails akzeptieren von';
$labels['blacklist_from'] = 'Mails ablehnen von';
$labels['whitelist_to'] = 'Akzeptiere Mails gesendet an';
$labels['addrule'] = 'Regel hinzufügen';
$labels['rule'] = 'Regel';
$labels['importfromaddressbook'] = 'Adressen aus dem Adressbuch importieren';
$labels['deleteall'] = 'Alle löschen';
$labels['autoscore'] = 'Automatisch';
$labels['defaultscore'] = 'Standardscore';
$labels['otherscore'] = 'Andere (%s)';
$labels['usedefault'] = 'Standardscore wiederherstellen';
$labels['langoptions'] = 'Sprachoptionen';
$labels['bayes'] = 'Bayes Einstellungen';
$labels['purgingbayes'] = 'Lösche bayesische Daten...';
$labels['purgebayes'] = 'Lösche persönliche bayesische Daten';
$labels['bayesautolearn'] = 'Bayes auto-lernen verwenden';
$labels['bayesautooptions'] = 'Auto-lernen Optionen';
$labels['bayesnonspam'] = '"Kein Spam" Schwellenwert';
$labels['bayesspam'] = '"Spam" Schwellenwert';
$labels['bayesrules'] = 'Bayesische Regeln verwenden';
$labels['help'] = 'Hilfe';

$messages = array();
$messages['sauserprefchanged'] = 'Spam Einstellungen erfolgreich geändert';
$messages['sauserpreffailed'] = 'Fehler: Spam-Einstellungen konnten nicht geändert werden';
$messages['spamthresexp'] = 'Alles über dem Schwellenwert wird als Spam markiert. Erhöhen des Schwellenwerts minimiert die verpassten Meldungen, aber erhöht die Möglichkeit der falschen Einstufung.';
$messages['spamlangexp'] = 'Wählen Sie alle Sprachen in denen Mails empfangen werden sollen. Alle nicht ausgewählten Sprachen werden als möglicher Spam markiert.';
$messages['headersexp'] = 'SpamAssassin fügt den verarbeiteten Mitteilungen Header mit Informationen über das Ergebnis zu. Verwende folgende Optionen um diese Header zu konfigurieren.';
$messages['spamtestssexp'] = 'Einige Checks verwenden Internet-baiserte Dienste um Spam besser identifizieren zu können. Wählen Sie, welche verwendet werden sollen:';
$messages['spamreport'] = 'Wird eine Mail als Spam identifiziert werden Berichte aller zugewiesenen Tests und Scores hinzugefügt...';
$messages['autowhitelist'] = 'Email Adressen aus dem Adressbuch werden automatisch zu der "Whitelist" hinzugefügt.';
$messages['whitelistexp'] = 'Ein (*) kann als Wildcard verwendet werden. Zum Beispiel: *@example.com oder *.example.com.';
$messages['spamaddressexists'] = 'Es existiert bereits eine Regel für diese Adresse';
$messages['spamenteraddress'] = 'Bitte eine hinzuzufügende Adresse eingeben';
$messages['spamaddresserror'] = 'Fehler: Die Adresse scheint ungültig zu sein';
$messages['spamaddressdelete'] = 'Sind Sie sicher, dass Sie diese Regel löschen möchten?';
$messages['spamaddressdeleteall'] = 'Sind Sie sicher, dass Sie alle Adressregeln löschen möchten?';
$messages['noaddressrules'] = 'Keine Adressregel gefunden.';
$messages['importingaddresses'] = 'Adressen werden importiert...';
$messages['usedefaultconfirm'] = 'Sind Sie sicher, dass Sie die Standardeinstellungen wiederherstellen möchten? Alle Einstellungen inklusive Adressregeln werden gelöscht.';
$messages['purgebayesexp'] = 'Gesammelte persönliche Bayesische Daten Ihrer Mails löschen.';
$messages['bayesnonspamexp'] = 'Mittelungen, deren Score unter diesem Schwellenwert liegen, werden verwendet um die "Ham" Erkennung zu verbessern.';
$messages['bayesspamexp'] = 'Mittelungen, deren Score über diesem Schwellenwert liegen, werden verwendet um die Spam-Erkennung zu verbessern.';
$messages['bayesautohelp'] = 'Wenn Bayes auto-lernen aktiviert ist, verwendet das System Mitteilungen die höchstwarscheinlich Spam/Ham sind um die Erkennungsfilter zu verbessern..';
$messages['bayeshelp'] = 'Die bayesische Klassifizierung versucht Spam anhand bekannter Wortfolgen zu identifizieren, die in Spam/Ham Mitteilungen gefunden wurde.';
$messages['rblhelp'] = 'Die Serveradressen der hypertext links einer Mitteilung werden mit Blacklists oder Listen bekannter Spamquellen verglichen.';
$messages['dcchelp'] = 'DCC (Distributed Checksum Clearinghouse) ist ein System aus Servern die Cheksummen von millionen von Mails sammeln und zählen. Dies Werte können verwendet werden um Spam zu erkennen.';
$messages['pyzhelp'] = 'Pyzor ist ein kollaboratives, vernetztes System, um Spam anhand eines Auszugs einer Mitteilung zu erkennen und zu blocken.';
$messages['raz2help'] = 'Vipul\'s Razor ist ein Prüfsummen-basiertes, verteiltes, gemeinschaftliches E-Mail-Spam-Erkennungs- und -Filter-Netzwerk. Razor basiert auf einem verteilten Spam-Katalog, der durch Benutzerrückmeldungen ständig aktualisiert wird. E-Mail-Clients und -Server können so bekannten Spam filtern. Die Erkennung erfolgt über statistische und randomisierte Signaturen.';
$messages['raz1help'] = 'Vipul\'s Razor ist ein Prüfsummen-basiertes, verteiltes, gemeinschaftliches E-Mail-Spam-Erkennungs- und -Filter-Netzwerk. Razor basiert auf einem verteilten Spam-Katalog, der durch Benutzerrückmeldungen ständig aktualisiert wird. E-Mail-Clients und -Server können so bekannten Spam filtern. Die Erkennung erfolgt über statistische und randomisierte Signaturen.';
$messages['levelhelp'] = 'Der \'Spam Level\' Header kann  Mitteilungen anhand von Zeichen, die sich eine bestimmte Anzahl mal wiederhohlen, hinzugefügt werden.';
$messages['foldhelp'] = 'Standardmäßig werden Header, die von SpamAssasin hinzugefügt werden, "whitespace foled". In anderen Worten: Sie werden auf mehrere Zeilen verteilt anstelle von einer sehr langen Zeile. Jeder andere Zeile wird ein Tabulator vorgesetzt um es als eine weiterführende Zeile der Vorhergehenden zu markieren.';
$messages['bayesruleshlp'] = 'Es empfiehlt sich, die "naive bayesische Stil Klassifizierung" zu verwenden. Damit können auch die Regeln deaktiviert werden auch wenn das automatisch und manuelle Lernen aktiviert ist.';
$messages['purgebayesconfirm'] = 'Sind Sie sicher, dass Sie alle bayesischen Daten löschen möchten?';
