<?php
/* Author: petrduchek */

$labels = array();
$labels['sauserprefs'] = 'Spam';
$labels['managespam'] = 'Spravovat nastavení detekce spamu';
$labels['sauserprefssettings'] = 'Nastavení spamu';
$labels['spamgeneralsettings'] = 'Všeobecné nastavení';
$labels['spamthres'] = 'Hranice skóre';
$labels['spamsubject'] = 'Značka v předmětu';
$labels['spamsubjectblank'] = '(zanechte prázdné pro žádnou)';
$labels['spamlang'] = 'Jazyky zprávy';
$labels['enabled'] = 'Povoleno';
$labels['disabled'] = 'Zakázáno';
$labels['headers'] = 'Hlavičky zpráv';
$labels['foldheaders'] = 'Povolit víceřádkové hlavičky';
$labels['spamlevelstars'] = 'Použít hlavičku \'Spam Level\' (úroveň spamu)';
$labels['spamlevelchar'] = 'Znak úrovně spamu';
$labels['spamtests'] = 'Internetové spam testy';
$labels['userazor1'] = 'Použít Razor v1';
$labels['userazor2'] = 'Použít Razor v2';
$labels['usepyzor'] = 'Použít Pyzor';
$labels['usebayes'] = 'Použít Bayesovský klasifikátor';
$labels['usedcc'] = 'Použít DCC';
$labels['skiprblchecks'] = 'Použít RBL';
$labels['spamreportsettings'] = 'Nastavení reportu';
$labels['spamreport0'] = 'Připojit oznámení do hlavičky originální zprávy';
$labels['spamreport1'] = 'Připojit originál jako MIME přílohu k oznámení';
$labels['spamreport2'] = 'Připojit originál jako textovou přílohu k oznámení';
$labels['spamaddressrules'] = 'Pravidla adres';
$labels['whitelist_from'] = 'Přijmout zprávu od';
$labels['blacklist_from'] = 'Odmítnout zprávu od';
$labels['whitelist_to'] = 'Přijímat zprávy zaslané pro';
$labels['addrule'] = 'Přidat';
$labels['rule'] = 'Pravidlo';
$labels['importfromaddressbook'] = 'Importovat adresy z adresáře';
$labels['deleteall'] = 'Odstranit vše';
$labels['autoscore'] = 'Auto';
$labels['defaultscore'] = 'Výchozí hodnocení';
$labels['otherscore'] = 'Ostatní (%s)';
$labels['usedefault'] = 'Obnovit výchozí nastavení';
$labels['langoptions'] = 'Jazyková nastavení';
$labels['bayes'] = 'Nastavení Bayesovského filtru';
$labels['purgingbayes'] = 'Odstraňuji Bayesovská data';
$labels['purgebayes'] = 'Odstranit vlastní Bayesovská data';
$labels['bayesautolearn'] = 'Použít automatické učení Bayesovského filtru';
$labels['bayesautooptions'] = 'Nastavení automatického učení';
$labels['bayesnonspam'] = 'Hranice pro ne-spam';
$labels['bayesspam'] = 'Hranice pro spam';
$labels['bayesrules'] = 'Použít Bayesovská pravidla';
$labels['help'] = 'Nápověda';

$messages = array();
$messages['sauserprefchanged'] = 'Nastavení spamu bylo úspěšně změněno';
$messages['sauserpreffailed'] = 'Chyba: Nastavení spamu se nepodařilo změnit';
$messages['spamthresexp'] = 'Veškeré e-maily se skóre vyšším něž je určená hranice budou označeny jako spam. Zvýšením této hranice sa zvýší počet nerozpoznaných spamů, na druhou stranu se sníží počet e-mailů chybně označených jako spam.';
$messages['spamlangexp'] = 'Vyberte veškeré jazyky ve kterých předpokladáte příjem e-mailů. Veškeré přijaté zprávy napsané v jiných jazycích budou brány jako pravděpodobný spam.';
$messages['headersexp'] = 'SpamAssassin přidává do kontrolovaných e-mailů hlavičky s informacemi o výsledcích kontroly. Použijte nasledující volby na jejich přizpůsobení.';
$messages['spamtestssexp'] = 'Některé testy při detekci spamu používají externí služby na internetu. Vyberte ty, které chcete využívat:';
$messages['spamreport'] = 'Pokud je e-mail identifikovaný jako spam, vytvoří se report o všech testech a jejich dosáhnutém skóre...';
$messages['autowhitelist'] = 'E-mailové adresy ve vašem Adresáři jsou automaticky přidány do listu "Přijmout zprávu od".';
$messages['whitelistexp'] = 'V e-mailových adresách může byť použitý zástupný znak hvězdička (*). Např.: *@domena.cz or *.domena.cz.';
$messages['spamaddressexists'] = 'Pravidlo pro tuto adresu již existuje';
$messages['spamenteraddress'] = 'Prosím zadajte adresu, kterou chcete přidat';
$messages['spamaddresserror'] = 'Chyba: Adresa se zdá neplatná';
$messages['spamaddressdelete'] = 'Jste si jisti, že chcete vymazat toto pravidlo?';
$messages['spamaddressdeleteall'] = 'Jste si jisti, že chcete vymazat všechny pravidla?';
$messages['noaddressrules'] = 'Nebyla nalezena žádná pravidla adres.';
$messages['importingaddresses'] = 'Importuji adresy...';
$messages['usedefaultconfirm'] = 'Jste si jisti, že chcete doopravdy obnovit předvolené nastavení? To vymaže všechny Vaše nastavení, včetně pravidel adres.';
$messages['purgebayesexp'] = 'Vymaže osobní Bayesovskou databázi vytvořenou z Vašich e-mailů';
$messages['bayesnonspamexp'] = 'E-maily s nižším skóre jak uvedená hranice budou použité na zlepšení detekce (naučení) ne-spamových zpráv.';
$messages['bayesspamexp'] = 'E-maily s vyšším skóre jak uvedená hranice budou použité na zlepšení detekce (naučení) spamových zpráv.';
$messages['bayesautohelp'] = 'Pokud je automatické učení zapnuto, systém použije zprávy které s velkou jistotou prohlásí za spam/ne-spam pro zlepšení detekčních filtrů.';
$messages['bayeshelp'] = 'Bayesovský klasifikátor se snaží identifikovat spam podle slov nebo shluku znaků, které sa obvykle vyskytují v spamových nebo ne-spamových e-mailech.';
$messages['rblhelp'] = 'IP adresy serverů v hlavičkách, nebo v odkazech v e-mailu budou vyhledané na některých blacklistech. Blacklisty jsou seznamy známých adres spammerů, které se aktualizují v reálném čase.';
$messages['dcchelp'] = 'DCC (distribuované výměnné centrum kontrolních součtů) je systém serverů sbírajících a vypočítavajících kontrolní součty (či podpisy) milionů e-mailů denně. Podle podobnosti kontrolního součtu příchozí zprávy vůči seznamu evidovaných se určuje pravděpodobnost spamu.';
$messages['pyzhelp'] = 'Pyzor je síťový systém na detekci a blokování spamu pomocí přehledu zpráv. Přehledy sa vypočítavají několika způsoby tak, aby dokázaly tolerovat malou změnu v obsahu zprávy.';
$messages['raz2help'] = 'Vipul\'s Razor je distribuovaná spolupracující síť na detekci a blokování spamu, pracující na základě užívateli zaslaných spamových vzorků. Tyto vzorky jsou zohledňovány podle reputace užívatele, který je poskytl. Detekce se tvoří pomocí charakteristik, které efektívně zachytávají i měnící se obsah spamu.';
$messages['raz1help'] = 'Vipul\'s Razor je distribuovaná spolupracující síť na detekci a blokování spamu, pracující na základě uživateli zaslaných spamových vzorků. Tyto vzorky jsou zohledňovány podle reputace uživatele, který je poskytl. Detekce sa tvoří pomocí charakteristík, které efektivně zachytávají i měnící se obsah spamu. Verzie 1 byla nahrzena verzí 2 a není už nadále podporována.';
$messages['levelhelp'] = 'Hlavička \'Spam Level\' zobrazuje opakovaním znaku (např. hvezdičky) skóre, které kontrolovaný e-mail získal. To může být užitečné při dalším zpracování e-mailu.';
$messages['foldhelp'] = 'Mohou být hlavičky přidané do e-mailu SpamAssassinem rozdělené na víc řádků, namísto toho, aby byly na jednom velmi dlouhém řádku? Pokud je řádek rozdělený, jeho pokračování je označeno odsazením.';
$messages['bayesruleshlp'] = 'Předtím, než může být Bayesovský klasifikátor efektivně použit, se musí natrénovat správné rozeznávání spamu od ne-spamu. Deaktivací Bayesovských pravidel systému umožníte pokračovat ve studiu jak automaticky, tak ručně z příchozí pošty, ale pravidla nebudou použity k detekci spamu.';
$messages['purgebayesconfirm'] = 'Jste si jisti, že chcete doopravdy vymazat celou Vaši Bayesovskou databázi?';
