<?php
/* Author: Sergey Khaliulov
   Updates: Tomasz Chiliński
*/

$labels = array();
$labels['sauserprefs'] = 'Spam';
$labels['managespam'] = 'Ustawienia wykrywania spamu';
$labels['sauserprefssettings'] = 'Ustawienia spamu';
$labels['spamgeneralsettings'] = 'Ustawienia główne';
$labels['spamthres'] = 'Próg punktowania';
$labels['spamsubject'] = 'Znacznik w temacie';
$labels['spamsubjectblank'] = '(zostaw puste jesli brak)';
$labels['spamlang'] = 'Język wiadomości';
$labels['enabled'] = 'Włączony';
$labels['disabled'] = 'Wyłączony';
$labels['headers'] = 'Nagłówki Wiadomości';
$labels['foldheaders'] = 'Zezwalaj na wiele linii w nagłówku';
$labels['spamlevelstars'] = 'Użyj nagłówka \'Spam Level\'';
$labels['spamlevelchar'] = 'Znacznik poziomu spamu';
$labels['spamtests'] = 'Testy Spamu oparte o internet';
$labels['userazor1'] = 'Użyj Razor v1';
$labels['userazor2'] = 'Użyj Razor v2';
$labels['usepyzor'] = 'Użyj Pyzor';
$labels['usebayes'] = 'Użyj klasyfikatora opartego na sieciach bayesowskich';
$labels['usedcc'] = 'Użyj DCC';
$labels['skiprblchecks'] = 'Użyj Realtime Blackhole List';
$labels['spamreportsettings'] = 'Opcje Raportu';
$labels['spamreport0'] = 'Dołącz raport w nagłówku oryginalnej wiadomości';
$labels['spamreport1'] = 'Dołącz orginał jako MIME załącznik do raportu';
$labels['spamreport2'] = 'Dołącz oryginał jako załącznik tekstowy';
$labels['spamaddressrules'] = 'Reguły Adresów';
$labels['whitelist_from'] = 'Akceptuj wiadomości od';
$labels['blacklist_from'] = 'Rejestruj wiadomości od';
$labels['whitelist_to'] = 'Akceptuj wiadomości wysłane do';
$labels['addrule'] = 'Dodaj regułę';
$labels['rule'] = 'Reguła';
$labels['importfromaddressbook'] = 'Importuj adresy z książki adresowej';
$labels['deleteall'] = 'Usuń wszystko';
$labels['autoscore'] = 'Automatycznie';
$labels['defaultscore'] = 'Domyślny Wynik';
$labels['otherscore'] = 'Inny (%s)';
$labels['usedefault'] = 'Przywróć ustawienia domyślne';
$labels['langoptions'] = 'Opcje Językowe';
$labels['bayes'] = 'Ustawienia sieci bayesowskich';
$labels['purgingbayes'] = 'Usuwanie sieci bayesowskich';
$labels['purgebayes'] = 'Usuwanie osobistych sieci bayesowskich';
$labels['bayesautolearn'] = 'Używaj automatycznego uczenia w oparciu o sieci bayesowkie';
$labels['bayesautooptions'] = 'Opcje automatycznego uczenia';
$labels['bayesnonspam'] = 'Próg nie spamu';
$labels['bayesspam'] = 'Próg spamu';
$labels['bayesrules'] = 'Używaj reguł sieci bayesowskich';
$labels['help'] = 'Pomoc';

$messages = array();
$messages['sauserprefchanged'] = 'Zmiany ustawień spamu zakończone sukcesem';
$messages['sauserpreffailed'] = 'Error: Nie można zmienić ustawień spamu';
$messages['spamthresexp'] = 'Wszystko powyżej progu jest oznaczane jako spam. Po zwiększeniu tego progu wzrośnie ilość spamu nieodebranego, ale zmniejszy się ryzyko fałszywych alarmów.';
$messages['spamlangexp'] = 'Wybierz wszystkie języki w jakich można oczekiwać, że otrzymasz wiadomości e-mail. Wszelkie wiadomości otrzymane, które są napisane w językach innych niż wybrane, będą traktowane jako spam.';
$messages['headersexp'] = 'SpamAssassin dodaje nagłówki przetworzonych wiadomości, dostarczające informacji o wynikach. Użyj poniższych opcji, aby skonfigurować te nagłówki.';
$messages['spamtestssexp'] = 'Niektóre kontrole wykorzystania usług internetowych w celu identyfikowania spamu. Wybierz te, których chcesz używać:';
$messages['spamreport'] = 'Gdy wiadomość jest klasyfikowana jako spam, tworzony jest raport z wszystkich testów.';
$messages['autowhitelist'] = 'Adresy w Twojej książce adresowej są automatycznie dodawane do listy akceptowanych nadawców.';
$messages['whitelistexp'] = 'Gwiazdka (*) zapewnia większą elastyczność. Na przykład: * @ example.com lub * @ *. example.com.';
$messages['spamaddressexists'] = 'Reguła dla tego adresu już istnieje';
$messages['spamenteraddress'] = 'Wpisz adres, który chcesz dodać';
$messages['spamaddresserror'] = 'Error: Niewłaściwy adres';
$messages['spamaddressdelete'] = 'Jesteś pewny, że chcesz usunąć tą regułę?';
$messages['spamaddressdeleteall'] = 'Jestes pewny, że chcesz usunąć wszystkie reguły adresowe?';
$messages['noaddressrules'] = 'Nie znaleziono reguły adresowej.';
$messages['importingaddresses'] = 'Wczytywanie adresów...';
$messages['usedefaultconfirm'] = 'Jesteś pewny, że chcesz przywrócić ustawienia domyślne? Usunie to wszystkie Twoje ustawienia, łącznie z regułami adresacji.';
$messages['purgebayesexp'] = 'Usuń osobistą sieć bayesowską utworzoną w oparciu o Twoje wiadomości';
$messages['bayesnonspamexp'] = 'Wiadomości z wartością poniżej tego progu będą użyte do poprawienia systemowej detekcji nie-spamu.';
$messages['bayesspamexp'] = 'Wiadomości z wartością powyżej tego progu będą użyte do poprawienia systemowej detekcji spamu.';
$messages['bayesautohelp'] = 'Kiedy włączone jest auto-uczenie się filtra słownikowego Bayes, system automatycznie przetworzy wiadomość która prawdopodobnie jest spamem/nie spamem aby ulepszyć filtry skanujące.';
$messages['bayeshelp'] = 'Klasyfikator oparty na sieciach bayesowskich próbuje zidentyfikować spam biorąc pod uwagę słowa lub krótkie sekwencje znaków, które są powszechnie spotykane w spamie lub wiadomościach niespamowych.';
$messages['rblhelp'] = 'Znalezione adresy serwerów zamieszczonych w linkach w hipertekście, będą sprawdzone na czarnej liście serwerów i znanych źródeł spamu.';
$messages['dcchelp'] = 'DCC inaczej Distributed Checksum Clearinghouse, to system serwerów przechowujący i zliczający sumy kontrolne milionów wiadomości dziennie. Im suma kontrolna otrzymanej wiadomości jest bardziej zbliżona do sum wiadomości na liście, tym bardziej prawdopodobne, że jest to spam.';
$messages['pyzhelp'] = 'Pyzor to sieciowy system wykrywania i blokowania spamu przy identyfikacji zarysu wiadomości. Zarysy są tworzone na wiele różnych sposobów, aby pozwolić na niewielkie różnice w treści wiadomości.';
$messages['raz2help'] = 'Vipul\'s Razor to rozproszona, społecznościowa sieć wykrywająca i filtrująca spam na podstawie zgłoszeń użytkowników. Wykrywanie odbywa się na podstawie sygnatur którymi oznaczane są treści spamu. Znaczniki wiarygodności użytkowników pomagają uwiarygodniać zgłoszenia spamu.';
$messages['raz1help'] = 'Vipul\'s Razor to rozproszona, społecznościowa sieć wykrywająca i filtrująca spam na podstawie zgłoszeń użytkowników. Wykrywanie odbywa się na podstawie sygnatur którymi oznaczane są treści spamu. Znaczniki wiarygodności użytkowników pomagają uwiarygodniać zgłoszenia spamu. Wersja 1 została zastąpiona przez wersję 2 i nie jest już wspierana.';
$messages['levelhelp'] = 'Nagłówek \'Poziom Spamu\' może zostać dodany do wiadomości aby uwidocznić punktację jaka otrzymała wiadmość, Znacznik zostanie powtórzony tyle razy ile punktów otrzymała wiadomość. Może to być pomocne przy następnych przetwarzaniach wiadomości.';
$messages['foldhelp'] = 'Czy zawijać nagłówki dodane przez SpamAssassina? Inaczej mówiąc czy mają być łamane w wielu liniach czy też pozostawione jako jedna długa linia. Kiedy linia jest dzielona zostaje oznaczona jako kontynuacja poprzedniej linii.';
$messages['bayesruleshlp'] = 'Słownikowy filtr Bayesa przed efektywnym użyciem musi przejść proces "trenowania" aby poprawnie wykrywać spam/nie spam. Wyłączenie reguł filtra Bayesa pozwoli systemowi na "uczenie" się zarówno automatycznie jak i ręcznie z nadchodzących wiadomości, ale wyniki działania filtrów nie będą używane do wykrywania spamu.';
$messages['purgebayesconfirm'] = 'Czy na pewno usunąć całą Twoją sieć bayesowską?';
