<roundcube:object name="doctype" value="html5" />
<html>
<head>
<title><roundcube:object name="pagetitle" /></title>
<roundcube:include file="/includes/links.html" />
<link rel="stylesheet" type="text/css" href="/this/sauserprefs.css" />
</head>
<roundcube:if condition="env:extwin" /><body class="noscroll extwin"><roundcube:else /><body class="noscroll"><roundcube:endif />

<roundcube:include file="/includes/header.html" />

<div id="mainscreen" class="offset">

<h1 class="voice"><roundcube:label name="settings" /> : <roundcube:label name="sauserprefs.sauserprefssettings" /></h1>

<roundcube:include file="/includes/settingstabs.html" />

<div id="settings-right">

<div id="sectionslist" class="uibox listbox" role="navigation" aria-labelledby="aria-label-pefsection">
<h2 id="aria-label-pefsection" class="boxtitle"><roundcube:label name="section" /></h2>
<div class="scroller">
	<roundcube:object name="sasectionslist" id="sections-table" class="listing iconized" noheader="true" />
</div>
</div>

<div id="preferences-box" class="uibox contentbox">
<div class="iframebox">
	<roundcube:object name="saprefsframe" id="preferences-frame" style="width:100%; height:100%" frameborder="0" src="/watermark.html" title="sauserprefs.arialabelspamform" />
</div>
</div>

</div>

</div>

<roundcube:include file="/includes/footer.html" />

<script type="text/javascript">
/* <![CDATA[ */

$(document).ready(function(){
	new rcube_splitter({id:'sauserprefssplitter', p1: '#sectionslist', p2: '#preferences-box', orientation: 'v', relative: true, start:266, min:180, size:12}).init();
});

/* ]]> */
</script>

</body>
</html>